==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/hr/languages.php <==
<?php
regGS("No language.", "Nema tog jezika");
regGS("Delete language $1", "Izbriši jezik $1");
regGS("You do not have the right to add languages.", "Nemate pravo dodavati jezike.");
regGS("Please enter the translation for time units.", "Molim unesite prijevod za jedinice vremena.");
regGS("Adding new language", "Dodavanje novog jezika");
regGS("The language $1 has been successfuly added.", "$1 jezik je uspješno dodan.");
regGS("Please check if a language with the same name does not already exist.", "Molim provjerite da li jezik s istim nazivom već postoji.");
regGS("The language could not be added.", "Jezik se ne može dodati.");
regGS("Delete language", "Izbriši jezik");
regGS("You do not have the right to delete languages.", "Nemate pravo brisati jezike");
regGS("Are you sure you want to delete the language $1?", "Zaista želite izbrisati $1 jezik?");
regGS("Deleting language", "Brisanje jezika");
regGS("The language $1 has been deleted.", "$1 jezik je izbrisan.");
regGS("The language $1 could not be deleted.", "$1 jezik se ne može izbrisati.");
regGS("Edit language", "Uredi jezik.");
regGS("You do not have the right to edit languages.", "Nemate pravo uređivati jezike.");
regGS("Please enter the translation for month names.", "Molim prevedite imena mjeseci u godini.");
regGS("Please enter the translation for week day names.", "Molim prevedite imena dana u tjednu.");
regGS("Updating language information", "Osvježi podatke o jeziku.");
regGS("Language information has been successfuly updated.", "Podaci o jeziku uspješno osvježeni.");
regGS("Language information could not be updated.", "Podaci o jeziku se ne mogu osvježiti.");
regGS("A language with the same name already exists.", "Jezik s istim imenom već postoji.");
regGS("January", "Siječanj");
regGS("February", "Veljača");
regGS("March", "Ožujak");
regGS("April", "Travanj");
regGS("May", "Svibanj");
regGS("June", "Lipanj");
regGS("July", "Srpanj");
regGS("August", "Kolovoz");
regGS("September", "Rujan");
regGS("October", "Listopad");
regGS("November", "Studeni");
regGS("December", "Prosinac");
regGS("Monday", "Ponedjeljak");
regGS("Tuesday", "Utorak");
regGS("Wednesday", "Srijeda");
regGS("Thursday", "Četvrtak");
regGS("Friday", "Petak");
regGS("Saturday", "Subota");
regGS("Sunday", "Nedjelja");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/hr/languages.php <==
<?php
regGS("No language.", "Nema tog jezika");
regGS("Delete language $1", "Izbriši jezik $1");
regGS("You do not have the right to add languages.", "Nemate ovlasti dodavati jezike.");
regGS("Please enter the translation for time units.", "Molim unesite prijevod za jedinice vremena.");
regGS("Adding new language", "Dodavanje novog jezika");
regGS("You do not have the right to delete languages.", "Nemate ovlasti brisati jezike.");
regGS("Are you sure you want to delete the language $1?", "Jeste li sigurni da želite obrisati $1 jezik?");
regGS("Deleting language", "Brisanje jezika");
regGS("The language $1 could not be deleted.", "$1 jezik se ne može obrisati.");
regGS("Edit language", "Uredi jezik.");
regGS("You do not have the right to edit languages.", "Nemate ovlasti uređivati jezike.");
regGS("Please enter the translation for month names.", "Molim prevedite imena mjeseci u godini.");
regGS("Please enter the translation for week day names.", "Molim prevedite imena dana u tjednu.");
regGS("January", "Siječanj");
regGS("February", "Veljača");
regGS("March", "Ožujak");
regGS("April", "Travanj");
regGS("May", "Svibanj");
regGS("June", "Lipanj");
regGS("July", "Srpanj");
regGS("August", "Kolovoz");
regGS("September", "Rujan");
regGS("October", "Listopad");
regGS("November", "Studeni");
regGS("December", "Prosinac");
regGS("Monday", "Ponedjeljak");
regGS("Tuesday", "Utorak");
regGS("Wednesday", "Srijeda");
regGS("Thursday", "Četvrtak");
regGS("Friday", "Petak");
regGS("Saturday", "Subota");
regGS("Sunday", "Nedjelja");
regGS("You do not have the right to add new languages.", "Nemate prava dodavati nove jezike.");
regGS("There are $1 issue(s) left.", "Ostalo je $1 izdanja.");
regGS("The language $1 has been successfuly added.", "$1 jezik je uspješno dodan.");
regGS("Please check if a language with the same name does not already exist.", "Molim provjerite da li jezik s istim nazivom već postoji.");
regGS("The language could not be added.", "Jezik se ne može dodati.");
regGS("Delete language", "Izbriši jezik");
regGS("The language $1 has been deleted.", "$1 jezik je obrisan.");
regGS("Updating language information", "Ažuriranje podataka o jeziku.");
regGS("Language information has been successfuly updated.", "Podaci o jeziku uspješno ažurirani.");
regGS("Language information could not be updated.", "Podaci o jeziku se ne mogu ažurirani.");
regGS("A language with the same name already exists.", "Jezik s istim imenom već postoji.");
?>
